==> pf4-component-mapper-3.16.0.tgz: package/esm/checkbox/multiple-choice-list.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["option"],
    _excluded2 = ["meta", "children"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { Checkbox } from "@patternfly/react-core/dist/esm/components/Checkbox/Checkbox.js";
import MultipleChoiceListCommon, { wrapperProps } from '@data-driven-forms/common/multiple-choice-list';
import FormGroup from '../form-group/form-group';

var FinalCheckbox = function FinalCheckbox(_ref) {
  var option = _ref.option,
      props = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement(Checkbox, _extends({
    isChecked: props.checked
  }, props, {
    onChange: function onChange(_value, e) {
      return props.onChange(e);
    }
  }, option));
};

FinalCheckbox.propTypes = {
  checked: PropTypes.bool,
  onChange: PropTypes.func.isRequired,
  option: PropTypes.object
};

var Wrapper = function Wrapper(_ref2) {
  var meta = _ref2.meta,
      children = _ref2.children,
      rest = _objectWithoutProperties(_ref2, _excluded2);

  return /*#__PURE__*/React.createElement(FormGroup, _extends({}, rest, {
    id: rest.name || rest.id,
    meta: meta
  }), children);
};

Wrapper.propTypes = _objectSpread({}, wrapperProps);

var MultipleChoiceList = function MultipleChoiceList(props) {
  return /*#__PURE__*/React.createElement(MultipleChoiceListCommon, _extends({}, props, {
    Wrapper: Wrapper,
    Checkbox: FinalCheckbox
  }));
};

export default MultipleChoiceList;

==> pf4-component-mapper-3.17.0.tgz: package/esm/checkbox/multiple-choice-list.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["option"],
    _excluded2 = ["meta", "children"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { Checkbox } from "@patternfly/react-core/dist/esm/components/Checkbox/Checkbox.js";
import MultipleChoiceListCommon, { wrapperProps } from '@data-driven-forms/common/multiple-choice-list';
import FormGroup from '../form-group/form-group';

var FinalCheckbox = function FinalCheckbox(_ref) {
  var option = _ref.option,
      props = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement(Checkbox, _extends({
    isChecked: props.checked
  }, props, {
    onChange: function onChange(_value, e) {
      return props.onChange(e);
    }
  }, option));
};

FinalCheckbox.propTypes = {
  checked: PropTypes.bool,
  onChange: PropTypes.func.isRequired,
  option: PropTypes.object
};

var Wrapper = function Wrapper(_ref2) {
  var meta = _ref2.meta,
      children = _ref2.children,
      rest = _objectWithoutProperties(_ref2, _excluded2);

  return /*#__PURE__*/React.createElement(FormGroup, _extends({}, rest, {
    id: rest.name || rest.id,
    meta: meta
  }), children);
};

Wrapper.propTypes = _objectSpread({}, wrapperProps);

var MultipleChoiceList = function MultipleChoiceList(props) {
  return /*#__PURE__*/React.createElement(MultipleChoiceListCommon, _extends({}, props, {
    Wrapper: Wrapper,
    Checkbox: FinalCheckbox
  }));
};

export default MultipleChoiceList;
